@@ -36,14 +36,18 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
      * (w,h)の大きさのA3Canvasを作ります。
      */
     public static A3Canvas createA3Canvas(int w,int h) {
+        GraphicsConfiguration gc = createGraphicsConfiguration();
+        return createA3Canvas(gc,w,h);
+    }
+
+    static GraphicsConfiguration createGraphicsConfiguration() {
         GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
         GraphicsDevice gd = ge.getDefaultScreenDevice();
         GraphicsConfiguration gcs[] = gd.getConfigurations();
         GraphicsConfigTemplate3D gct3d = new GraphicsConfigTemplate3D();
         GraphicsConfiguration gc = gct3d.getBestConfiguration(gcs);
-        return createA3Canvas(gc,w,h);
+        return gc;
     }
-
     /**
      * GraphicsConfigurationオブジェクトを指定して
      * (500,500)の大きさのA3Canvasを作ります。
@@ -57,10 +61,26 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
      * (w,h)の大きさのA3Canvasを作ります。
      */
     public static A3Canvas createA3Canvas(GraphicsConfiguration graCon,int w,int h) {
-         return new A3Canvas(graCon,w,h);
+        return new A3Canvas(graCon,w,h);
     }
 
-    A3Canvas(GraphicsConfiguration graCon,int w,int h) {
+    /**
+     * (500,500)の大きさのA3Canvasを作ります。
+     */
+    public A3Canvas() {
+        this(500,500);
+    }
+    /**
+     * (w,h)の大きさのA3Canvasを作ります。
+     */
+    public A3Canvas(int w,int h) {
+        this(createGraphicsConfiguration(),w,h);
+    }
+    /**
+     * GraphicsConfigurationオブジェクトを指定して
+     * (w,h)の大きさのA3Canvasを作ります。
+     */
+    public A3Canvas(GraphicsConfiguration graCon,int w,int h) {
         //super(graCon.getDevice());
         super(graCon);
         gc = getGraphicsContext3D();
