@@ -97,15 +97,25 @@ public interface A3CanvasInterface {
     public void setDefaultCameraQuat(Quat4d quat);
 
     /**
-     * カメラのデフォルトの回転を指定します。
+     * カメラのデフォルトの回転を指定します(ラジアン版)。
      */
     public void setDefaultCameraRot(double x,double y,double z);
 
     /**
-     * カメラのデフォルトの回転を指定します。
+     * カメラのデフォルトの回転を指定します(ラジアン版)。
      */
     public void setDefaultCameraRot(Vector3d rot);
 
+    /**
+     * カメラのデフォルトの回転を指定します(デグリー版)。
+     */
+    public void setDefaultCameraRev(double x,double y,double z);
+
+    /**
+     * カメラのデフォルトの回転を指定します(デグリー版)。
+     */
+    public void setDefaultCameraRev(Vector3d rev);
+
     /**
      * カメラのデフォルトの拡大率を指定します。
      */
@@ -223,58 +233,119 @@ public interface A3CanvasInterface {
     public Quat4d getCameraTargetQuat();
 
     /**
-     * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
-     * 変ります。
+     * カメラの回転を指定します(オイラー角をラジアンで指定:x,y,z版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
      */
     public void setCameraRot(double x,double y,double z);
 
     /**
-     * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
-     * 変ります。
+     * カメラの回転を指定します(オイラー角をラジアンで指定:Vector3d版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
      */
     public void setCameraRot(Vector3d rot);
 
     /**
-     * カメラの回転を即時に指定します。
+     * カメラの回転を即時に指定します(オイラー角をラジアンで指定:x,y,z版)。
      */
     public void setCameraRotImmediately(double x,double y,double z);
 
     /**
-     * カメラの回転を即時に指定します。
+     * カメラの回転を即時に指定します(オイラー角をラジアンで指定:Vector3d版)。
      */
     public void setCameraRotImmediately(Vector3d rot);
 
     /**
-     * 現在のカメラの回転に引数で与えられた回転を合成します。
+     * 現在のカメラの回転に引数で与えられた回転を
+     * 合成します(オイラー角をラジアンで指定:x,y,z版)。
      */
     public void mulCameraRot(double x,double y,double z);
 
     /**
-     * 現在のカメラの回転に引数で与えられた回転を合成します。
+     * 現在のカメラの回転に引数で与えられた回転を
+     * 合成します(オイラー角をラジアンで指定:Vector3d版)。
      */
     public void mulCameraRot(Vector3d rot);
 
     /**
-     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をラジアンで指定:x,y,z版)。
      */
     public void mulCameraRotImmediately(double x,double y,double z);
 
     /**
-     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をラジアンで指定:Vector3d版)。
      */
     public void mulCameraRotImmediately(Vector3d rot);
 
     /**
-     * カメラの現在の回転を返します。
+     * カメラの現在の回転を返します(オイラー角をラジアンで取得)。
      */
     public Vector3d getCameraRot();
 
     /**
-     * カメラの目標回転を返します。
+     * カメラの目標回転を返します(オイラー角をラジアンで取得)。
      * カメラは常に補完が効いているので最終的に到達する回転という意味です。
      */
     public Vector3d getCameraTargetRot();
 
+    /**
+     * カメラの回転を指定します(オイラー角をデグリーで指定:x,y,z版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
+     */
+    public void setCameraRev(double x,double y,double z);
+
+    /**
+     * カメラの回転を指定します(オイラー角をデグリーで指定:Vector3d版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
+     */
+    public void setCameraRev(Vector3d rev);
+
+    /**
+     * カメラの回転を即時に指定します(オイラー角をデグリーで指定:x,y,z版)。
+     */
+    public void setCameraRevImmediately(double x,double y,double z);
+
+    /**
+     * カメラの回転を即時に指定します(オイラー角をデグリーで指定:Vector3d版)。
+     */
+    public void setCameraRevImmediately(Vector3d rev);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を
+     * 合成します(オイラー角をデグリーで指定:x,y,z版)。
+     */
+    public void mulCameraRev(double x,double y,double z);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を
+     * 合成します(オイラー角をデグリーで指定:Vector3d版)。
+     */
+    public void mulCameraRev(Vector3d rev);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をデグリーで指定:x,y,z版)。
+     */
+    public void mulCameraRevImmediately(double x,double y,double z);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して
+     * 即時に反映させます(オイラー角をデグリーで指定:Vector3d版)。
+     */
+    public void mulCameraRevImmediately(Vector3d rev);
+
+    /**
+     * カメラの現在の回転を返します(オイラー角をデグリーで取得)。
+     */
+    public Vector3d getCameraRev();
+
+    /**
+     * カメラの目標回転を返します(オイラー角をデグリーで取得)。
+     * カメラは常に補完が効いているので最終的に到達する回転という意味です。
+     */
+    public Vector3d getCameraTargetRev();
+
     /**
      * カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
      * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
@@ -582,15 +653,25 @@ public interface A3CanvasInterface {
     public void setDefaultCameraQuat(Quat4d quat,int scene);
 
     /**
-     * シーンを指定して、カメラのデフォルトの回転を指定します。
+     * シーンを指定して、カメラのデフォルトの回転を指定します(ラジアン版)。
      */
     public void setDefaultCameraRot(double x,double y,double z,int scene);
 
     /**
-     * シーンを指定して、カメラのデフォルトの回転を指定します。
+     * シーンを指定して、カメラのデフォルトの回転を指定します(ラジアン版)。
      */
     public void setDefaultCameraRot(Vector3d rot,int scene);
 
+    /**
+     * シーンを指定して、カメラのデフォルトの回転を指定します(デグリー版)。
+     */
+    public void setDefaultCameraRev(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、カメラのデフォルトの回転を指定します(デグリー版)。
+     */
+    public void setDefaultCameraRev(Vector3d rev,int scene);
+
     /**
      * シーンを指定して、カメラのデフォルトの拡大率を指定します。
      */
@@ -708,58 +789,119 @@ public interface A3CanvasInterface {
     public Quat4d getCameraTargetQuat(int scene);
 
     /**
-     * シーンを指定して、カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
-     * 変ります。
+     * シーンを指定して、カメラの回転を指定します(ラジアン版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
      */
     public void setCameraRot(double x,double y,double z,int scene);
 
     /**
-     * シーンを指定して、カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
-     * 変ります。
+     * シーンを指定して、カメラの回転を指定します(ラジアン版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
      */
     public void setCameraRot(Vector3d rot,int scene);
 
     /**
-     * シーンを指定して、カメラの回転を即時に指定します。
+     * シーンを指定して、カメラの回転を即時に指定します(ラジアン版)。
      */
     public void setCameraRotImmediately(double x,double y,double z,int scene);
 
     /**
-     * シーンを指定して、カメラの回転を即時に指定します。
+     * シーンを指定して、カメラの回転を即時に指定します(ラジアン版)。
      */
     public void setCameraRotImmediately(Vector3d rot,int scene);
 
     /**
-     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成します。
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成します(ラジアン版)。
      */
     public void mulCameraRot(double x,double y,double z,int scene);
 
     /**
-     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成します。
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成します(ラジアン版)。
      */
     public void mulCameraRot(Vector3d rot,int scene);
 
     /**
-     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(ラジアン版)。
      */
     public void mulCameraRotImmediately(double x,double y,double z,int scene);
 
     /**
-     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(ラジアン版)。
      */
     public void mulCameraRotImmediately(Vector3d rot,int scene);
 
     /**
-     * シーンを指定して、カメラの現在の回転を返します。
+     * シーンを指定して、カメラの現在の回転を返します(ラジアン版)。
      */
     public Vector3d getCameraRot(int scene);
 
     /**
-     * シーンを指定して、カメラの目標回転を返します。
+     * シーンを指定して、カメラの目標回転を返します(ラジアン版)。
      * カメラは常に補完が効いているので最終的に到達する回転という意味です。
      */
     public Vector3d getCameraTargetRot(int scene);
 
+    /**
+     * シーンを指定して、カメラの回転を指定します(デグリー版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
+     */
+    public void setCameraRev(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を指定します(デグリー版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
+     */
+    public void setCameraRev(Vector3d rev,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(デグリー版)。
+     */
+    public void setCameraRevImmediately(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(デグリー版)。
+     */
+    public void setCameraRevImmediately(Vector3d rev,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成します(デグリー版)。
+     */
+    public void mulCameraRev(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成します(デグリー版)。
+     */
+    public void mulCameraRev(Vector3d rev,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(デグリー版)。
+     */
+    public void mulCameraRevImmediately(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた
+     * 回転を合成して即時に反映させます(デグリー版)。
+     */
+    public void mulCameraRevImmediately(Vector3d rev,int scene);
+
+    /**
+     * シーンを指定して、カメラの現在の回転を返します(デグリー版)。
+     */
+    public Vector3d getCameraRev(int scene);
+
+    /**
+     * シーンを指定して、カメラの目標回転を返します(デグリー版)。
+     * カメラは常に補完が効いているので最終的に到達する回転という意味です。
+     */
+    public Vector3d getCameraTargetRev(int scene);
+
     /**
      * シーンを指定して、カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
      * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
@@ -853,7 +995,7 @@ public interface A3CanvasInterface {
      * シーンを指定して、ナビゲーションモードを指定します。
      * 必要であればナビゲーションの初期化に必要なパラメータも渡してやります。
      */
-    public void setNavigationMode(NaviMode m,int scene,Object...params);
+    public void setNavigationMode(int scene,NaviMode m,Object...params);
 
     /**
      * シーンを指定して、ナビゲーションの大まかなスピードを設定します。
