@@ -504,7 +504,112 @@ public abstract class A3Object {
     public final Vector3d getTargetRot() {
         return Util.quat2euler(getTargetQuat());
     }
-    
+
+
+    /**
+     * 回転をセットするためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRev(Vector3d rev) {
+        setQuat(Util.euler2quat(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z));
+    }
+
+    /**
+     * 回転をセットするためのメソッド(オイラー角をデグリーで指定:x,y,z版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRev(double x, double y,double z) {
+        setQuat(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRevImmediately(Vector3d rev) {
+        setQuatImmediately(Util.euler2quat(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z));
+    }
+
+    /**
+     * 回転を即座にセットするためのメソッド(オイラー角をデグリーで指定:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void setRevImmediately(double x,double y,double z) {
+        setQuatImmediately(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
+    }
+
+    /**
+     * 現在の回転に引数の回転を合成するためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRev(Vector3d rev) {
+        mulQuat(Util.euler2quat(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z));
+    }
+
+    /**
+     * 現在の回転に引数の回転を合成するためのメソッド(オイラー角をデグリーで指定:x,y,z版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRev(double x, double y,double z) {
+        mulQuat(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRevImmediately(Vector3d rev) {
+        mulQuatImmediately(Util.euler2quat(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角をデグリーで指定:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRevImmediately(double x,double y,double z) {
+        mulQuatImmediately(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
+    }
+
+    /**
+     * 現在の回転を取得するためのメソッド(オイラー角をデグリーで取得:Vector3d版)。
+     */
+    public final Vector3d getRev() {
+        Vector3d rev = Util.quat2euler(getQuat());
+        rev.scale(180.0/Math.PI);
+        return rev;
+    }
+
+    /**
+     * 目標回転を取得するためのメソッド(オイラー角をデグリーで取得:Vector3d版)。
+     * setEnableBehavior(false)の場合はgetRotと同じだが、
+     * setEnableBehavior(true)の場合は目標回転を返す。
+     */
+    public final Vector3d getTargetRev() {
+        Vector3d rev = Util.quat2euler(getTargetQuat());
+        rev.scale(180.0/Math.PI);
+        return rev;
+    }
+ 
     /**
      * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
      * 指定した座標に向くように回転をセットします。その時の計算に
@@ -582,21 +687,223 @@ public abstract class A3Object {
     }
 
     /**
-     * 現在の拡大率を取得するためのメソッド。
+     * X軸方向の拡大率をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setScaleX(double sx) {
+        behavior.setScaleX(sx);
+    }
+
+    /**
+     * Y軸方向の拡大率をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setScaleY(double sy) {
+        behavior.setScaleY(sy);
+    }
+
+    /**
+     * Z軸方向の拡大率をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setScaleZ(double sz) {
+        behavior.setScaleZ(sz);
+    }
+
+    /**
+     * X,Y,Z軸方向の拡大率をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setScale(Vector3d sv) {
+        behavior.setScale(sv);
+    }
+
+    /**
+     * X軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleXImmediately(double sx) {
+        behavior.setScaleXImmediately(sx);
+    }
+
+    /**
+     * Y軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleYImmediately(double sy) {
+        behavior.setScaleYImmediately(sy);
+    }
+
+    /**
+     * Z軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleZImmediately(double sz) {
+        behavior.setScaleZImmediately(sz);
+    }
+
+    /**
+     * X,Y,Z軸の拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleImmediately(Vector3d sv) {
+        behavior.setScaleImmediately(sv);
+    }
+
+    /**
+     * 現在のX軸の拡大率に引数の数値をかけてセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulScaleX(double sx) {
+        behavior.mulScaleX(sx);
+    }
+
+    /**
+     * 現在のY軸の拡大率に引数の数値をかけてセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulScaleY(double sy) {
+        behavior.mulScaleY(sy);
+    }
+
+    /**
+     * 現在のZ軸の拡大率に引数の数値をかけてセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulScaleZ(double sz) {
+        behavior.mulScaleZ(sz);
+    }
+
+    /**
+     * 現在のX,Y,Z軸の拡大率に引数の数値をかけてセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulScale(Vector3d sv) {
+        behavior.mulScale(sv);
+    }
+
+    /**
+     * 現在のX軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleXImmediately(double sx) {
+        behavior.mulScaleXImmediately(sx);
+    }
+
+    /**
+     * 現在のY軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleYImmediately(double sy) {
+        behavior.mulScaleYImmediately(sy);
+    }
+
+    /**
+     * 現在のZ軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleZImmediately(double sz) {
+        behavior.mulScaleZImmediately(sz);
+    }
+
+    /**
+     * 現在のX,Y,Z軸の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleImmediately(Vector3d sv) {
+        behavior.mulScaleImmediately(sv);
+    }
+
+    /**
+     * 現在の拡大率を取得するためのメソッド。もし、X,Y,Z軸の
+     * 拡大率が異なる場合には、その平均を返します。
      */
     public final double getScale() {
         return behavior.getScale();
     }
 
+    /**
+     * 現在のX軸方向の拡大率を取得するためのメソッド。
+     */
+    public final double getScaleX() {
+        return behavior.getScaleX();
+    }
+
+    /**
+     * 現在のY軸方向の拡大率を取得するためのメソッド。
+     */
+    public final double getScaleY() {
+        return behavior.getScaleY();
+    }
+
+    /**
+     * 現在のZ軸方向の拡大率を取得するためのメソッド。
+     */
+    public final double getScaleZ() {
+        return behavior.getScaleZ();
+    }
+
+    /**
+     * 現在のX,Y,Z軸方向の拡大率を取得するためのメソッド。
+     */
+    public final Vector3d getScaleV() {
+        return behavior.getScaleV();
+    }
+
     /**
      * 目標拡大率を取得するためのメソッド。
+     * もし、X,Y,Z軸の目標拡大率が異なる場合には、その平均を返します。
      * setEnableBehavior(false)の場合はgetScaleと同じだが、
      * setEnableBehavior(true)の場合は目標拡大率を返す。
      */
     public final double getTargetScale() {
         return behavior.getTargetScale();
     }
-    
+
+    /**
+     * X軸の目標拡大率を取得するためのメソッド。
+     * setEnableBehavior(false)の場合はgetScaleXと同じだが、
+     * setEnableBehavior(true)の場合は目標拡大率を返す。
+     */
+    public final double getTargetScaleX() {
+        return behavior.getTargetScale();
+    }
+
+    /**
+     * Y軸の目標拡大率を取得するためのメソッド。
+     * setEnableBehavior(false)の場合はgetScaleYと同じだが、
+     * setEnableBehavior(true)の場合は目標拡大率を返す。
+     */
+    public final double getTargetScaleY() {
+        return behavior.getTargetScaleY();
+    }
+
+    /**
+     * Z軸の目標拡大率を取得するためのメソッド。
+     * setEnableBehavior(false)の場合はgetScaleZと同じだが、
+     * setEnableBehavior(true)の場合は目標拡大率を返す。
+     */
+    public final double getTargetScaleZ() {
+        return behavior.getTargetScaleZ();
+    }
+
+    /**
+     * X,Y,Z軸の目標拡大率を取得するためのメソッド。
+     * setEnableBehavior(false)の場合はgetScaleVと同じだが、
+     * setEnableBehavior(true)の場合は目標拡大率を返す。
+     */
+    public final Vector3d getTargetScaleV() {
+        return behavior.getTargetScaleV();
+    }
+
     /**
      * このオブジェクトのローカルな座標系のX軸がグローバルな
      * 仮想空間の座標系ではどちらの方向になるのかを返します。
