@@ -49,12 +49,17 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
      * (w,h)の大きさのA3Canvasを作ります。
      */
     public static A3SubCanvas createA3SubCanvas(int w,int h) {
+        GraphicsConfiguration gc = createGraphicsConfiguration();
+        return createA3SubCanvas(gc,w,h);
+    }
+
+    static GraphicsConfiguration createGraphicsConfiguration() {
         GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
         GraphicsDevice gd = ge.getDefaultScreenDevice();
         GraphicsConfiguration gcs[] = gd.getConfigurations();
         GraphicsConfigTemplate3D gct3d = new GraphicsConfigTemplate3D();
         GraphicsConfiguration gc = gct3d.getBestConfiguration(gcs);
-        return createA3SubCanvas(gc,w,h);
+        return gc;
     }
 
     /**
@@ -73,7 +78,25 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         return new A3SubCanvas(graCon,w,h);
     }
 
-    A3SubCanvas(GraphicsConfiguration graCon,int w,int h) {
+    /**
+     * (500,500)の大きさのA3Canvasを作ります。
+     */
+    public A3SubCanvas() {
+        this(500,500);
+    }
+
+    /**
+     * (w,h)の大きさのA3Canvasを作ります。
+     */
+    public A3SubCanvas(int w,int h) {
+        this(createGraphicsConfiguration(),w,h);
+    }
+
+    /**
+     * GraphicsConfigurationオブジェクトを指定して
+     * (w,h)の大きさのA3SubCanvasを作ります。
+     */
+    public A3SubCanvas(GraphicsConfiguration graCon,int w,int h) {
         //super(graCon.getDevice());
         super(graCon);
         //gc = getGraphicsContext3D();
