@@ -29,22 +29,29 @@ public class A3Window extends JFrame implements A3CanvasInterface {
      * (w,h)の大きさのA3Windowを生成します。
      */
     public A3Window(int w,int h) {
-        addWindowListener(new WindowAdapter() {
-            public void windowClosing(WindowEvent we) {
-                dispose();
-                System.exit(0);
-            }
-        });
-        canvas = A3Canvas.createA3Canvas(w,h);
-        getContentPane().add(canvas);
-        pack();
-        setVisible(true);
-        EventQueue.invokeLater(new Runnable() {
-            public void run() {
-                System.out.println("invokeLater");
-                canvas.requestFocusInWindow();
-            }
-        });
+        final int ww = w;
+        final int hh = h;
+        try {
+            EventQueue.invokeAndWait(new Runnable() {
+                public void run() {
+
+                    addWindowListener(new WindowAdapter() {
+                        public void windowClosing(WindowEvent we) {
+                            dispose();
+                            System.exit(0);
+                        }
+                    });
+                    canvas = A3Canvas.createA3Canvas(ww,hh);
+                    getContentPane().add(canvas);
+                    pack();
+                    setVisible(true);
+
+                    canvas.requestFocusInWindow();
+                }
+            });
+        } catch (Exception e) {
+            e.printStackTrace();
+        }
     }
 
     /**
