@@ -44,21 +44,47 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
      * (w,h)の大きさのJA3Canvasを作ります。
      */
     public static JA3Canvas createJA3Canvas(int w,int h) {
-        GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
-        GraphicsDevice gd = ge.getDefaultScreenDevice();
-        GraphicsConfigTemplate3D gct3d = new GraphicsConfigTemplate3D();
+        GraphicsDevice gd = createGraphicsDevice();
+        GraphicsConfigTemplate3D gct3d = createGraphicsConfigTemplate3D();
         return createJA3Canvas(gct3d,gd,w,h);
     }
 
+    static GraphicsDevice createGraphicsDevice() {
+        GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
+        GraphicsDevice gd = ge.getDefaultScreenDevice();
+        return gd;
+    }
+    static GraphicsConfigTemplate3D createGraphicsConfigTemplate3D() {
+        GraphicsConfigTemplate3D gct3d = new GraphicsConfigTemplate3D();
+        return gct3d;
+    }
+
     /**
-     * GraphicsConfigurationオブジェクトを指定して
+     * GraphicsConfigTemplate3DとGraphicsDeviceオブジェクトを指定して
      * (w,h)の大きさのA3Canvasを作ります。
      */
     public static JA3Canvas createJA3Canvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
         return new JA3Canvas(t,d,w,h);
     }
 
-    JA3Canvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
+    /**
+     * (500,500)の大きさのJA3Canvasを作成します。
+     */
+    public JA3Canvas() {
+        this(500,500);
+    }
+    /**
+     * (w,h)の大きさのJA3Canvasを作ります。
+     */
+    public JA3Canvas(int w,int h) {
+        this(createGraphicsConfigTemplate3D(),createGraphicsDevice(),w,h);
+    }
+
+    /**
+     * GraphicsConfigTemplate3DとGraphicsDeviceオブジェクトを指定して
+     * (w,h)の大きさのA3Canvasを作ります。
+     */
+    public JA3Canvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
         super(t,d);
         setPreferredSize(new Dimension(w,h));
         setSize(w,h);
