@@ -42,31 +42,58 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
     ArrayList<Runnable> renderingLoopTasks = new ArrayList<Runnable>();
 
     /**
-     * (500,500)の大きさのJA3Canvasを作成します。
+     * (500,500)の大きさのJA3SubCanvasを作成します。
      */
     public static JA3SubCanvas createJA3SubCanvas() {
         return createJA3SubCanvas(500,500);
     }
 
     /**
-     * (w,h)の大きさのJA3Canvasを作ります。
+     * (w,h)の大きさのJA3SubCanvasを作ります。
      */
     public static JA3SubCanvas createJA3SubCanvas(int w,int h) {
-        GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
-        GraphicsDevice gd = ge.getDefaultScreenDevice();
-        GraphicsConfigTemplate3D gct3d = new GraphicsConfigTemplate3D();
+        GraphicsDevice gd = createGraphicsDevice();
+        GraphicsConfigTemplate3D gct3d = createGraphicsConfigTemplate3D();
         return createJA3SubCanvas(gct3d,gd,w,h);
     }
 
+    static GraphicsDevice createGraphicsDevice() {
+        GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
+        GraphicsDevice gd = ge.getDefaultScreenDevice();
+        return gd;
+    }
+    static GraphicsConfigTemplate3D createGraphicsConfigTemplate3D() {
+        GraphicsConfigTemplate3D gct3d = new GraphicsConfigTemplate3D();
+        return gct3d;
+    }
+
     /**
-     * GraphicsConfigurationオブジェクトを指定して
-     * (w,h)の大きさのA3Canvasを作ります。
+     * GraphicsConfigTemplate3DとGraphicsDeviceオブジェクトを指定して
+     * (w,h)の大きさのA3SubCanvasを作ります。
      */
     public static JA3SubCanvas createJA3SubCanvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
         return new JA3SubCanvas(t,d,w,h);
     }
 
-    JA3SubCanvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
+    /**
+     * (500,500)の大きさのJA3SubCanvasを作ります。
+     */
+    public JA3SubCanvas() {
+        this(500,500);
+    }
+
+    /**
+     * (w,h)の大きさのJA3SubCanvasを作ります。
+     */
+    public JA3SubCanvas(int w,int h) {
+        this(createGraphicsConfigTemplate3D(),createGraphicsDevice(),w,h);
+    }
+
+    /**
+     * GraphicsConfigTemplate3DとGraphicsDeviceオブジェクトを指定して
+     * (w,h)の大きさのA3SubCanvasを作ります。
+     */
+    public JA3SubCanvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
         super(t,d);
         setPreferredSize(new Dimension(w,h));
         setSize(w,h);
@@ -177,6 +204,16 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         subCamBehavior.setDefaultCameraRot(rot);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z) {
+        subCamBehavior.setDefaultCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev) {
+        subCamBehavior.setDefaultCameraRev(rev);
+    }
+
     @Override
     public void setDefaultCameraScale(double s) {
         subCamBehavior.setDefaultCameraScale(s);
@@ -337,6 +374,56 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return subCamBehavior.getCameraTargetRot();
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z) {
+        subCamBehavior.setCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev) {
+        subCamBehavior.setCameraRev(rev);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z) {
+        subCamBehavior.setCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev) {
+        subCamBehavior.setCameraRevImmediately(rev);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z) {
+        subCamBehavior.mulCameraRev(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev) {
+        subCamBehavior.mulCameraRev(rev);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z) {
+        subCamBehavior.mulCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev) {
+        subCamBehavior.mulCameraRevImmediately(rev);
+    }
+
+    @Override
+    public Vector3d getCameraRev() {
+        return subCamBehavior.getCameraRev();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev() {
+        return subCamBehavior.getCameraTargetRev();
+    }
+
     @Override
     public void setCameraScale(double s) {
         subCamBehavior.setCameraScale(s);
@@ -1584,6 +1671,116 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return null;
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRev(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRev(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRevImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setCameraRevImmediately(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRev(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRev(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRevImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraRev(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraTargetRev(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1695,6 +1892,28 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setDefaultCameraRev(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void setDefaultCameraRev(Vector3d rev, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1712,7 +1931,7 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
      * 後のバージョンでは廃止する予定です。
      */
     @Override
-    public void setNavigationMode(NaviMode m, int scene,Object...params) {
+    public void setNavigationMode(int scene,NaviMode m,Object...params) {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
