@@ -503,8 +503,8 @@ public class Util {
         ShapeHull sh = new ShapeHull(chs1);
         sh.buildHull(margin);
         ObjectArrayList<Vector3f> vertexes2 = sh.getVertexPointer();
-        System.out.println("v1:"+vertexes1.size());
-        System.out.println("v2:"+vertexes2.size());
+//System.out.println("v1:"+vertexes1.size());
+//System.out.println("v2:"+vertexes2.size());
         ConvexHullShape chs2 = new ConvexHullShape(vertexes2);
         return chs2;
     }
@@ -588,8 +588,8 @@ public class Util {
         int totalVerts = iTmp[0];
         int totalTriangles = iTmp[1];
 
-System.out.println("totalVerts:"+totalVerts);
-System.out.println("totalTriangles:"+totalTriangles);
+//System.out.println("totalVerts:"+totalVerts);
+//System.out.println("totalTriangles:"+totalTriangles);
 
         ByteBuffer vertices = ByteBuffer.allocateDirect(totalVerts * vertStride).order(ByteOrder.nativeOrder());
         ByteBuffer gIndices = ByteBuffer.allocateDirect(totalTriangles * 3 * 4).order(ByteOrder.nativeOrder());
